==> vertx-sql-common-3.4.0-sources.jar: io/vertx/groovy/ext/sql/SQLConnection_GroovyExtension.java <==
package io.vertx.groovy.ext.sql;
public class SQLConnection_GroovyExtension {
  public static io.vertx.ext.sql.SQLConnection query(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.groovy.ext.sql.internal.ConversionHelper.wrap(j_receiver.query(sql,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> io.vertx.groovy.ext.sql.internal.ConversionHelper.applyIfNotNull(event, a -> io.vertx.groovy.ext.sql.internal.ConversionHelper.fromJsonObject(a.toJson()))));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection queryWithParams(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, java.util.List<Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.groovy.ext.sql.internal.ConversionHelper.wrap(j_receiver.queryWithParams(sql,
      params != null ? io.vertx.groovy.ext.sql.internal.ConversionHelper.toJsonArray(params) : null,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> io.vertx.groovy.ext.sql.internal.ConversionHelper.applyIfNotNull(event, a -> io.vertx.groovy.ext.sql.internal.ConversionHelper.fromJsonObject(a.toJson()))));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection queryStreamWithParams(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, java.util.List<Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.SQLRowStream>> handler) {
    io.vertx.groovy.ext.sql.internal.ConversionHelper.wrap(j_receiver.queryStreamWithParams(sql,
      params != null ? io.vertx.groovy.ext.sql.internal.ConversionHelper.toJsonArray(params) : null,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.SQLRowStream>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.SQLRowStream> ar) {
        handler.handle(ar.map(event -> io.vertx.groovy.ext.sql.internal.ConversionHelper.wrap(event)));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection update(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.groovy.ext.sql.internal.ConversionHelper.wrap(j_receiver.update(sql,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult> ar) {
        resultHandler.handle(ar.map(event -> io.vertx.groovy.ext.sql.internal.ConversionHelper.applyIfNotNull(event, a -> io.vertx.groovy.ext.sql.internal.ConversionHelper.fromJsonObject(a.toJson()))));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection updateWithParams(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, java.util.List<Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.groovy.ext.sql.internal.ConversionHelper.wrap(j_receiver.updateWithParams(sql,
      params != null ? io.vertx.groovy.ext.sql.internal.ConversionHelper.toJsonArray(params) : null,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult> ar) {
        resultHandler.handle(ar.map(event -> io.vertx.groovy.ext.sql.internal.ConversionHelper.applyIfNotNull(event, a -> io.vertx.groovy.ext.sql.internal.ConversionHelper.fromJsonObject(a.toJson()))));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection call(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.groovy.ext.sql.internal.ConversionHelper.wrap(j_receiver.call(sql,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> io.vertx.groovy.ext.sql.internal.ConversionHelper.applyIfNotNull(event, a -> io.vertx.groovy.ext.sql.internal.ConversionHelper.fromJsonObject(a.toJson()))));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection callWithParams(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, java.util.List<Object> params, java.util.List<Object> outputs, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.groovy.ext.sql.internal.ConversionHelper.wrap(j_receiver.callWithParams(sql,
      params != null ? io.vertx.groovy.ext.sql.internal.ConversionHelper.toJsonArray(params) : null,
      outputs != null ? io.vertx.groovy.ext.sql.internal.ConversionHelper.toJsonArray(outputs) : null,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> io.vertx.groovy.ext.sql.internal.ConversionHelper.applyIfNotNull(event, a -> io.vertx.groovy.ext.sql.internal.ConversionHelper.fromJsonObject(a.toJson()))));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection batchWithParams(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sqlStatement, java.util.List<java.util.List<Object>> args, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<java.lang.Integer>>> handler) {
    io.vertx.groovy.ext.sql.internal.ConversionHelper.wrap(j_receiver.batchWithParams(sqlStatement,
      args != null ? args.stream().map(elt -> elt != null ? io.vertx.groovy.ext.sql.internal.ConversionHelper.toJsonArray(elt) : null).collect(java.util.stream.Collectors.toList()) : null,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<java.lang.Integer>>>() {
      public void handle(io.vertx.core.AsyncResult<java.util.List<java.lang.Integer>> ar) {
        handler.handle(ar.map(event -> io.vertx.groovy.ext.sql.internal.ConversionHelper.applyIfNotNull(event, list -> list.stream().map(elt -> elt).collect(java.util.stream.Collectors.toList()))));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection batchCallableWithParams(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sqlStatement, java.util.List<java.util.List<Object>> inArgs, java.util.List<java.util.List<Object>> outArgs, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<java.lang.Integer>>> handler) {
    io.vertx.groovy.ext.sql.internal.ConversionHelper.wrap(j_receiver.batchCallableWithParams(sqlStatement,
      inArgs != null ? inArgs.stream().map(elt -> elt != null ? io.vertx.groovy.ext.sql.internal.ConversionHelper.toJsonArray(elt) : null).collect(java.util.stream.Collectors.toList()) : null,
      outArgs != null ? outArgs.stream().map(elt -> elt != null ? io.vertx.groovy.ext.sql.internal.ConversionHelper.toJsonArray(elt) : null).collect(java.util.stream.Collectors.toList()) : null,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<java.lang.Integer>>>() {
      public void handle(io.vertx.core.AsyncResult<java.util.List<java.lang.Integer>> ar) {
        handler.handle(ar.map(event -> io.vertx.groovy.ext.sql.internal.ConversionHelper.applyIfNotNull(event, list -> list.stream().map(elt -> elt).collect(java.util.stream.Collectors.toList()))));
      }
    } : null));
    return j_receiver;
  }
}

==> vertx-sql-common-3.4.2-sources.jar: io/vertx/groovy/ext/sql/SQLConnection_GroovyExtension.java <==
package io.vertx.groovy.ext.sql;
public class SQLConnection_GroovyExtension {
  public static io.vertx.ext.sql.SQLConnection query(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.query(sql,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection queryWithParams(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, java.util.List<Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.queryWithParams(sql,
      params != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(params) : null,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection queryStreamWithParams(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, java.util.List<Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.SQLRowStream>> handler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.queryStreamWithParams(sql,
      params != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(params) : null,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.SQLRowStream>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.SQLRowStream> ar) {
        handler.handle(ar.map(event -> io.vertx.core.impl.ConversionHelper.fromObject(event)));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection update(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.update(sql,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection updateWithParams(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, java.util.List<Object> params, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.updateWithParams(sql,
      params != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(params) : null,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.UpdateResult> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection call(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.call(sql,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection callWithParams(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sql, java.util.List<Object> params, java.util.List<Object> outputs, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.Map<String, Object>>> resultHandler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.callWithParams(sql,
      params != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(params) : null,
      outputs != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(outputs) : null,
      resultHandler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet>>() {
      public void handle(io.vertx.core.AsyncResult<io.vertx.ext.sql.ResultSet> ar) {
        resultHandler.handle(ar.map(event -> event != null ? io.vertx.core.impl.ConversionHelper.fromJsonObject(event.toJson()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection batchWithParams(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sqlStatement, java.util.List<java.util.List<Object>> args, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<java.lang.Integer>>> handler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.batchWithParams(sqlStatement,
      args != null ? args.stream().map(elt -> elt != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(elt) : null).collect(java.util.stream.Collectors.toList()) : null,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<java.lang.Integer>>>() {
      public void handle(io.vertx.core.AsyncResult<java.util.List<java.lang.Integer>> ar) {
        handler.handle(ar.map(event -> event != null ? event.stream().map(elt -> elt).collect(java.util.stream.Collectors.toList()) : null));
      }
    } : null));
    return j_receiver;
  }
  public static io.vertx.ext.sql.SQLConnection batchCallableWithParams(io.vertx.ext.sql.SQLConnection j_receiver, java.lang.String sqlStatement, java.util.List<java.util.List<Object>> inArgs, java.util.List<java.util.List<Object>> outArgs, io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<java.lang.Integer>>> handler) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.batchCallableWithParams(sqlStatement,
      inArgs != null ? inArgs.stream().map(elt -> elt != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(elt) : null).collect(java.util.stream.Collectors.toList()) : null,
      outArgs != null ? outArgs.stream().map(elt -> elt != null ? io.vertx.core.impl.ConversionHelper.toJsonArray(elt) : null).collect(java.util.stream.Collectors.toList()) : null,
      handler != null ? new io.vertx.core.Handler<io.vertx.core.AsyncResult<java.util.List<java.lang.Integer>>>() {
      public void handle(io.vertx.core.AsyncResult<java.util.List<java.lang.Integer>> ar) {
        handler.handle(ar.map(event -> event != null ? event.stream().map(elt -> elt).collect(java.util.stream.Collectors.toList()) : null));
      }
    } : null));
    return j_receiver;
  }
}
